import { runMdx } from "@/lib/mdx/run";
import { mdxComponents } from "@/lib/mdx/components";
import Head from "next/head";
import { BlogPost } from "./type";

interface Props {
	post: BlogPost;
}

export const BlogPostMain = (props: Props): JSX.Element => {
	const { code } = props.post;
	const { Content, meta } = runMdx(code);
	const title = meta?.title ?? null;
	const date = meta?.date ?? null;
	return (
		<>
			{date ? <p>{date}</p> : null}
			{title ? <h1>{title}</h1> : null}
			<Content components={mdxComponents} />
			{/* Below Content so it overrides the title generated by Content's
			headings */}
			{title ? (
				<Head>
					<title>{title}</title>
				</Head>
			) : null}
		</>
	);
};
